==> jc-1.4.0.tar.gz: java/util/jar/JarFile__24JarEnumeration.h <==
// class java.util.jar.JarFile$JarEnumeration

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 6ad8de92bcd73e39 java_util_jar_JarFile__24JarEnumeration

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_java_util_jar_JarFile__24JarEnumeration_H_
#define _JC_java_util_jar_JarFile__24JarEnumeration_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_util_Enumeration$object;
struct _jc_java_util_jar_JarFile$object;

// Typedefs
typedef struct _jc_java_util_jar_JarFile__24JarEnumeration$sub_refs	_jc_java_util_jar_JarFile__24JarEnumeration$sub_refs;
typedef struct _jc_java_util_jar_JarFile__24JarEnumeration$sub_nonrefs	_jc_java_util_jar_JarFile__24JarEnumeration$sub_nonrefs;
typedef struct _jc_java_util_jar_JarFile__24JarEnumeration$refs	_jc_java_util_jar_JarFile__24JarEnumeration$refs;
typedef struct _jc_java_util_jar_JarFile__24JarEnumeration$nonrefs	_jc_java_util_jar_JarFile__24JarEnumeration$nonrefs;
typedef struct _jc_java_util_jar_JarFile__24JarEnumeration$object	_jc_java_util_jar_JarFile__24JarEnumeration$object;

typedef const struct _jc_java_util_jar_JarFile__24JarEnumeration$vmethods	_jc_java_util_jar_JarFile__24JarEnumeration$vmethods;
typedef const struct _jc_java_util_jar_JarFile__24JarEnumeration$vtable	_jc_java_util_jar_JarFile__24JarEnumeration$vtable;
typedef const struct _jc_java_util_jar_JarFile__24JarEnumeration$vtype	_jc_java_util_jar_JarFile__24JarEnumeration$vtype;

// Constructors
extern void _jc_java_util_jar_JarFile__24JarEnumeration$method$_init$ba70ce8d071df0ce(_jc_env *, struct _jc_java_util_jar_JarFile__24JarEnumeration$object *, struct _jc_object *, struct _jc_java_util_jar_JarFile$object *);

// Virtual methods
extern jboolean _jc_java_util_jar_JarFile__24JarEnumeration$method$hasMoreElements$95fbe58f36adadb0(_jc_env *, struct _jc_java_util_jar_JarFile__24JarEnumeration$object *);
extern struct _jc_java_lang_Object$object *_jc_java_util_jar_JarFile__24JarEnumeration$method$nextElement$9b7c3789fa3ba818(_jc_env *, struct _jc_java_util_jar_JarFile__24JarEnumeration$object *);

// Virtual method descriptors
extern _jc_method _jc_java_util_jar_JarFile__24JarEnumeration$method_info$hasMoreElements$95fbe58f36adadb0;
extern _jc_method _jc_java_util_jar_JarFile__24JarEnumeration$method_info$nextElement$9b7c3789fa3ba818;

// Virtual methods structure
struct _jc_java_util_jar_JarFile__24JarEnumeration$vmethods {
	jboolean	(*hasMoreElements$95fbe58f36adadb0)(_jc_env *, struct _jc_java_util_jar_JarFile__24JarEnumeration$object *);
	struct _jc_java_lang_Object$object	*(*nextElement$9b7c3789fa3ba818)(_jc_env *, struct _jc_java_util_jar_JarFile__24JarEnumeration$object *);
};

// Vtable
struct _jc_java_util_jar_JarFile__24JarEnumeration$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_util_jar_JarFile__24JarEnumeration$vmethods	java_util_jar_JarFile__24JarEnumeration;
};

// Vtype
struct _jc_java_util_jar_JarFile__24JarEnumeration$vtype {
	_jc_type			type;
	_jc_java_util_jar_JarFile__24JarEnumeration$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_util_jar_JarFile__24JarEnumeration$sub_refs {
	struct _jc_object	*entries;
	struct _jc_java_util_jar_JarFile$object	*jarfile;
};

// Reference instance fields (object)
struct _jc_java_util_jar_JarFile__24JarEnumeration$refs {
    _jc_java_util_jar_JarFile__24JarEnumeration$sub_refs	java_util_jar_JarFile__24JarEnumeration;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_util_jar_JarFile__24JarEnumeration$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_util_jar_JarFile__24JarEnumeration$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_util_jar_JarFile__24JarEnumeration$sub_nonrefs	java_util_jar_JarFile__24JarEnumeration;
};

// Object instance structure
struct _jc_java_util_jar_JarFile__24JarEnumeration$object {
	_jc_java_util_jar_JarFile__24JarEnumeration$refs	refs[0];
	_jc_word		lockword;
	_jc_java_util_jar_JarFile__24JarEnumeration$vtype	*vtype;
	_jc_java_util_jar_JarFile__24JarEnumeration$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_util_jar_JarFile__24JarEnumeration$vtype _jc_java_util_jar_JarFile__24JarEnumeration$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_util_jar_JarFile__24JarEnumeration, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_util_jar_JarFile__24JarEnumeration$class_object;

#endif	/* _JC_java_util_jar_JarFile__24JarEnumeration_H_ */

==> jc-1.4.5.tar.gz: java/util/jar/JarFile__24JarEnumeration.h <==
// class java.util.jar.JarFile$JarEnumeration

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 6ad8de92bcd73e39 java_util_jar_JarFile__24JarEnumeration

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_java_util_jar_JarFile__24JarEnumeration_H_
#define _JC_java_util_jar_JarFile__24JarEnumeration_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_util_Enumeration$object;
struct _jc_java_util_jar_JarFile$object;

// Typedefs
typedef struct _jc_java_util_jar_JarFile__24JarEnumeration$sub_refs	_jc_java_util_jar_JarFile__24JarEnumeration$sub_refs;
typedef struct _jc_java_util_jar_JarFile__24JarEnumeration$sub_nonrefs	_jc_java_util_jar_JarFile__24JarEnumeration$sub_nonrefs;
typedef struct _jc_java_util_jar_JarFile__24JarEnumeration$refs	_jc_java_util_jar_JarFile__24JarEnumeration$refs;
typedef struct _jc_java_util_jar_JarFile__24JarEnumeration$nonrefs	_jc_java_util_jar_JarFile__24JarEnumeration$nonrefs;
typedef struct _jc_java_util_jar_JarFile__24JarEnumeration$object	_jc_java_util_jar_JarFile__24JarEnumeration$object;

typedef const struct _jc_java_util_jar_JarFile__24JarEnumeration$vmethods	_jc_java_util_jar_JarFile__24JarEnumeration$vmethods;
typedef const struct _jc_java_util_jar_JarFile__24JarEnumeration$vtable	_jc_java_util_jar_JarFile__24JarEnumeration$vtable;
typedef const struct _jc_java_util_jar_JarFile__24JarEnumeration$vtype	_jc_java_util_jar_JarFile__24JarEnumeration$vtype;

// Constructors
extern void _jc_java_util_jar_JarFile__24JarEnumeration$method$_init$ba70ce8d071df0ce(_jc_env *, struct _jc_java_util_jar_JarFile__24JarEnumeration$object *, struct _jc_object *, struct _jc_java_util_jar_JarFile$object *) _JC_JCNI_ATTR;

// Virtual methods
extern jboolean _jc_java_util_jar_JarFile__24JarEnumeration$method$hasMoreElements$95fbe58f36adadb0(_jc_env *, struct _jc_java_util_jar_JarFile__24JarEnumeration$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_Object$object *_jc_java_util_jar_JarFile__24JarEnumeration$method$nextElement$9b7c3789fa3ba818(_jc_env *, struct _jc_java_util_jar_JarFile__24JarEnumeration$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_java_util_jar_JarFile__24JarEnumeration$method_info$hasMoreElements$95fbe58f36adadb0;
extern _jc_method _jc_java_util_jar_JarFile__24JarEnumeration$method_info$nextElement$9b7c3789fa3ba818;

// Virtual methods structure
struct _jc_java_util_jar_JarFile__24JarEnumeration$vmethods {
	jboolean	(*hasMoreElements$95fbe58f36adadb0)(_jc_env *, struct _jc_java_util_jar_JarFile__24JarEnumeration$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_Object$object	*(*nextElement$9b7c3789fa3ba818)(_jc_env *, struct _jc_java_util_jar_JarFile__24JarEnumeration$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_java_util_jar_JarFile__24JarEnumeration$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_util_jar_JarFile__24JarEnumeration$vmethods	java_util_jar_JarFile__24JarEnumeration;
};

// Vtype
struct _jc_java_util_jar_JarFile__24JarEnumeration$vtype {
	_jc_type			type;
	_jc_java_util_jar_JarFile__24JarEnumeration$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_util_jar_JarFile__24JarEnumeration$sub_refs {
	struct _jc_object	*entries;
	struct _jc_java_util_jar_JarFile$object	*jarfile;
};

// Reference instance fields (object)
struct _jc_java_util_jar_JarFile__24JarEnumeration$refs {
    _jc_java_util_jar_JarFile__24JarEnumeration$sub_refs	java_util_jar_JarFile__24JarEnumeration;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_util_jar_JarFile__24JarEnumeration$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_util_jar_JarFile__24JarEnumeration$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_util_jar_JarFile__24JarEnumeration$sub_nonrefs	java_util_jar_JarFile__24JarEnumeration;
};

// Object instance structure
struct _jc_java_util_jar_JarFile__24JarEnumeration$object {
	_jc_java_util_jar_JarFile__24JarEnumeration$refs	refs[0];
	_jc_word		lockword;
	_jc_java_util_jar_JarFile__24JarEnumeration$vtype	*vtype;
	_jc_java_util_jar_JarFile__24JarEnumeration$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_util_jar_JarFile__24JarEnumeration$vtype _jc_java_util_jar_JarFile__24JarEnumeration$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_util_jar_JarFile__24JarEnumeration, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_util_jar_JarFile__24JarEnumeration$class_object;

#endif	/* _JC_java_util_jar_JarFile__24JarEnumeration_H_ */
